@@ -27,15 +27,22 @@ impl Frame {
     /// Maximize the window
     pub fn show_maximized(&self) {
         use windows_sys::Win32::UI::WindowsAndMessaging::ShowWindow;
-        use windows_sys::Win32::UI::WindowsAndMessaging::SW_SHOWMAXIMIZED;
-        unsafe { ShowWindow(self.handle,SW_SHOWMAXIMIZED); }
+        use windows_sys::Win32::UI::WindowsAndMessaging::SW_MAXIMIZE;
+        unsafe { ShowWindow(self.handle,SW_MAXIMIZE); }
     }
 
     /// Minimize the window
     pub fn show_minimized(&self) {
         use windows_sys::Win32::UI::WindowsAndMessaging::ShowWindow;
-        use windows_sys::Win32::UI::WindowsAndMessaging::SW_SHOWMINIMIZED;
-        unsafe { ShowWindow(self.handle,SW_SHOWMINIMIZED); }
+        use windows_sys::Win32::UI::WindowsAndMessaging::SW_MINIMIZE;
+        unsafe { ShowWindow(self.handle,SW_MINIMIZE); }
+    }
+
+    /// Hide the window
+    pub fn hide(&self) {
+        use windows_sys::Win32::UI::WindowsAndMessaging::ShowWindow;
+        use windows_sys::Win32::UI::WindowsAndMessaging::SW_HIDE;
+        unsafe { ShowWindow(self.handle,SW_HIDE); }
     }
 
     /// Set window title
@@ -91,7 +98,6 @@ pub trait Application {
     fn ui(&self,frame: Frame);
     /// Processing at application termination (optional)
     fn exit(&self) {
-
     }
 }
 
@@ -129,6 +135,24 @@ impl Frame {
         use gtk::prelude::*;
         self.handle.unmaximize();
     }
+
+    /// Hide the window
+    pub fn hide(&self) {
+        use gtk::prelude::*;
+        self.handle.hide();
+    }
+
+    /// Set window title
+    pub fn set_title(&self,title: String) {
+        use gtk::prelude::*;
+        self.handle.set_title(title.as_str());
+    }
+
+    /// Set window position
+    pub fn set_position(&self,x: i32,y: i32) {
+        use gtk::prelude::*;
+        self.handle.set_window_position(gtk::WindowPosition::Center);
+    }
 }
 
 #[cfg(unix)]
